##  Cloning a Fact Sheet
Cloning fact sheets is particularly useful when you need to create a successor fact sheet or when you are creating multiple similar fact sheets in the initial stage of populating your workspace. For example, multiple similar IT components with different release versions. While cloning, you can already establish the new fact sheet's relationship to the current one as a successor or predecessor.
A cloned fact sheet includes the following data from the original fact sheet:
  * All attributes
  * All relations, except one-to-one relations (to avoid exceeding defined limits)
  * All attached documents and resources


Comments, surveys, and metrics are not included in the clone.
**Note**
You can clone a fact sheet only if you have the appropriate CRUD (Create, Read, Update, Delete) permissions for fields and fact sheets.
To clone a fact sheet, follow these steps:
  1. In the top right of the fact sheet, click the clone icon.
  2. In the resulting overlay, provide the name of the new fact sheet and fill in other fields as needed.
  3. Click Clone.


![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio0411944d292e4505a7e16c0f85ea973f_LowRes.png)
Cloning a Fact Sheet
